from datetime import datetime
from pathlib import Path

import pytest
from cal_tools.plotting import show_processed_modules
from cal_tools.tools import get_dir_creation_date


def test_show_processed_modules():
    mnames = ['Q1M1']

    with pytest.raises(ValueError) as err:
        show_processed_modules('LDP', mnames=mnames,
                               constants={}, mode='processed')
        assert 'LDP' in err.value()


def test_dir_creation_date():
    folder = '/gpfs/exfel/exp/DETLAB/202031/p900172/raw'

    date = get_dir_creation_date(folder, 10)
    assert isinstance(date, datetime)
    assert str(date) == '2020-07-20 10:39:03'

    with pytest.raises(ValueError) as e:
        get_dir_creation_date(folder, 4)
    assert e.value.args[1] == Path(folder) / 'r0004'

    # The following data predates the addition of creation_time in metadata
    folder = '/gpfs/exfel/exp/SQS/201930/p900075/raw/'

    date = get_dir_creation_date(folder, 365)
    assert isinstance(date, datetime)
    assert str(date) == '2019-07-04 11:02:41.280000'
